==> italent-task-operate-area-5.1.5.tgz: package/lib/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import React, { Component } from 'react';
import { OperateWrap, Line, OperateRight } from './style';
import TimeSelector from './component/timeSelector';
import ExpiredSelector from './component/expiredSelector';
import OrderSelector from './component/orderSelector';
import FilterSelector from './component/filterSelector';
import ModeSelector from './component/modeSelector';
import './icon/font/style.css';
import produce from 'immer';

var OperateArea =
/*#__PURE__*/
function (_Component) {
  _inherits(OperateArea, _Component);

  function OperateArea(p) {
    var _this;

    _classCallCheck(this, OperateArea);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(OperateArea).call(this, p));

    _this.selectTime = function (data) {
      //选择时间
      _this.setState({
        dateScope: _this.fixDateScope(data),
        orderBy: _this.props.operateInfo.orderBy
      });

      _this.props.selectTime(data);
    };

    _this.fixDateScope = function (data) {
      var dateScope = _this.state.dateScope;
      return produce(dateScope, function (draft) {
        draft.usual.map(function (u) {
          u.selected = data ? data.id === u.id : false;
        });
      });
    };

    _this.fixOrderBy = function () {
      var orderBy = _this.state.orderBy;
      return produce(orderBy, function (draft) {
        draft.map(function (order) {
          order.selected = order.id == 4;
        });
      });
    };

    _this.showExpiredTask = function () {
      //过期任务
      var orderBy = _this.state.orderBy;
      var selectedOrder = orderBy.filter(function (order) {
        return order.selected;
      })[0];

      _this.setState({
        dateScope: _this.fixDateScope(),
        orderBy: _this.fixOrderBy()
      });

      _this.props.showExpiredTask(selectedOrder);
    };

    _this.selectOrder = function (d) {
      //选中排序
      var orderBy = _this.state.orderBy;
      var orders = produce(orderBy, function (draft) {
        draft.map(function (order) {
          order.selected = order.id == d.id;
        });
      });

      _this.setState({
        orderBy: orders
      });

      _this.props.selectOrder(d);
    };

    _this.changeMode = function (d) {
      //切换模式
      var mode = _this.state.mode;
      var newMode = produce(mode, function (draft) {
        draft.map(function (m) {
          m.selected = m.id == d.id;
        });
      });

      _this.setState({
        mode: newMode
      });

      _this.props.changeMode(d);
    };

    _this.state = {
      dateScope: p.operateInfo.dateScope,
      orderBy: p.operateInfo.orderBy,
      mode: p.operateInfo.mode // window.addEventListener('resize', this.getPullLeft, false)

    };
    return _this;
  }

  _createClass(OperateArea, [{
    key: "componentWillUnmount",
    value: function componentWillUnmount() {// window.removeEventListener('resize', this.getPullLeft, false)
    }
  }, {
    key: "componentWillUpdate",
    value: function componentWillUpdate() {
      var dateScope = this.props.operateInfo.dateScope;

      if (JSON.stringify(this.state.dateScope.usual) !== JSON.stringify(dateScope.usual)) {
        this.setState({
          dateScope: dateScope
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          _this$props$operateIn = _this$props.operateInfo,
          expiredTaskNum = _this$props$operateIn.expiredTaskNum,
          filterData = _this$props$operateIn.filterData,
          selectFilter = _this$props.selectFilter,
          selectedExpire = _this$props.selectedExpire,
          chargeUsers = _this$props.chargeUsers,
          outStyle = _this$props.outStyle,
          hideOrder = _this$props.hideOrder;
      var _this$state = this.state,
          dateScope = _this$state.dateScope,
          mode = _this$state.mode,
          orderBy = _this$state.orderBy;
      return React.createElement(OperateWrap, {
        style: outStyle,
        className: "operate-wrap"
      }, React.createElement(TimeSelector, {
        data: dateScope,
        selectTime: this.selectTime
      }), React.createElement(Line, {
        show: dateScope && !!expiredTaskNum
      }), React.createElement(ExpiredSelector, {
        selected: selectedExpire,
        showExpiredTask: this.showExpiredTask,
        data: expiredTaskNum
      }), React.createElement(OperateRight, null, !hideOrder && React.createElement(OrderSelector, {
        isExpire: selectedExpire,
        data: orderBy,
        selectOrder: this.selectOrder
      }), React.createElement(FilterSelector, {
        data: filterData,
        selectFilter: selectFilter,
        chargeUsers: chargeUsers
      }), React.createElement(ModeSelector, {
        data: mode,
        changeMode: this.changeMode
      })));
    }
  }]);

  return OperateArea;
}(Component); // trigger ci 4


export { OperateArea as default };

==> italent-task-operate-area-5.1.6.tgz: package/lib/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import React, { Component } from 'react';
import { OperateWrap, Line, OperateRight } from './style';
import TimeSelector from './component/timeSelector';
import ExpiredSelector from './component/expiredSelector';
import OrderSelector from './component/orderSelector';
import FilterSelector from './component/filterSelector';
import ModeSelector from './component/modeSelector';
import './icon/font/style.css';
import produce from 'immer';

var OperateArea =
/*#__PURE__*/
function (_Component) {
  _inherits(OperateArea, _Component);

  function OperateArea(p) {
    var _this;

    _classCallCheck(this, OperateArea);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(OperateArea).call(this, p));

    _this.selectTime = function (data) {
      //选择时间
      _this.setState({
        dateScope: _this.fixDateScope(data),
        orderBy: _this.props.operateInfo.orderBy
      });

      _this.props.selectTime(data);
    };

    _this.fixDateScope = function (data) {
      var dateScope = _this.state.dateScope;
      return produce(dateScope, function (draft) {
        draft.usual.map(function (u) {
          u.selected = data ? data.id === u.id : false;
        });
      });
    };

    _this.fixOrderBy = function () {
      var orderBy = _this.state.orderBy;
      return produce(orderBy, function (draft) {
        draft.map(function (order) {
          order.selected = order.id == 4;
        });
      });
    };

    _this.showExpiredTask = function () {
      //过期任务
      var orderBy = _this.state.orderBy;
      var selectedOrder = orderBy.filter(function (order) {
        return order.selected;
      })[0];

      _this.setState({
        dateScope: _this.fixDateScope(),
        orderBy: _this.fixOrderBy()
      });

      _this.props.showExpiredTask(selectedOrder);
    };

    _this.selectOrder = function (d) {
      //选中排序
      var orderBy = _this.state.orderBy;
      var orders = produce(orderBy, function (draft) {
        draft.map(function (order) {
          order.selected = order.id == d.id;
        });
      });

      _this.setState({
        orderBy: orders
      });

      _this.props.selectOrder(d);
    };

    _this.changeMode = function (d) {
      //切换模式
      var mode = _this.state.mode;
      var newMode = produce(mode, function (draft) {
        draft.map(function (m) {
          m.selected = m.id == d.id;
        });
      });

      _this.setState({
        mode: newMode
      });

      _this.props.changeMode(d);
    };

    _this.state = {
      dateScope: p.operateInfo.dateScope,
      orderBy: p.operateInfo.orderBy,
      mode: p.operateInfo.mode
    };
    return _this;
  }

  _createClass(OperateArea, [{
    key: "componentWillUpdate",
    value: function componentWillUpdate() {
      var dateScope = this.props.operateInfo.dateScope;
      var selectedExpire = this.props.selectedExpire;

      if (!selectedExpire && JSON.stringify(this.state.dateScope.usual) !== JSON.stringify(dateScope.usual)) {
        this.setState({
          dateScope: dateScope
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          _this$props$operateIn = _this$props.operateInfo,
          expiredTaskNum = _this$props$operateIn.expiredTaskNum,
          filterData = _this$props$operateIn.filterData,
          selectFilter = _this$props.selectFilter,
          selectedExpire = _this$props.selectedExpire,
          chargeUsers = _this$props.chargeUsers,
          outStyle = _this$props.outStyle,
          hideOrder = _this$props.hideOrder;
      var _this$state = this.state,
          dateScope = _this$state.dateScope,
          mode = _this$state.mode,
          orderBy = _this$state.orderBy;
      return React.createElement(OperateWrap, {
        style: outStyle,
        className: "operate-wrap"
      }, React.createElement(TimeSelector, {
        data: dateScope,
        selectTime: this.selectTime
      }), React.createElement(Line, {
        show: dateScope && !!expiredTaskNum
      }), React.createElement(ExpiredSelector, {
        selected: selectedExpire,
        showExpiredTask: this.showExpiredTask,
        data: expiredTaskNum
      }), React.createElement(OperateRight, null, !hideOrder && React.createElement(OrderSelector, {
        isExpire: selectedExpire,
        data: orderBy,
        selectOrder: this.selectOrder
      }), React.createElement(FilterSelector, {
        data: filterData,
        selectFilter: selectFilter,
        chargeUsers: chargeUsers
      }), React.createElement(ModeSelector, {
        data: mode,
        changeMode: this.changeMode
      })));
    }
  }]);

  return OperateArea;
}(Component); // trigger ci 4


export { OperateArea as default };
